@@ -677,12 +677,12 @@ void dw_sbvar_variance_decomposition_command_line(int nargs, char **args)
 		sprintf(buffer=(char*)dw_malloc(strlen(fmt) + 10),fmt,s);
 		out_filename=CreateFilenameFromTag(buffer,cmd->out_tag,cmd->out_directory);
 		dw_free(buffer);
-		if (f_out=fopen(out_filename,"wt"))
+		if ((f_out=fopen(out_filename,"wt")))
 		  {		
 		    printf("Constructing variance decomposition - regime %d\n",s);
 		    if (percentiles)
 		      {
-			if (histogram=variance_decomposition_percentiles_regime(posterior_file,thin,s,horizon,model,type))
+			if ((histogram=variance_decomposition_percentiles_regime(posterior_file,thin,s,horizon,model,type)))
 			  {
 			    tvd=CreateMatrix(horizon,p->nvars*p->nvars);
 			    for (i=0; i < DimV(percentiles); i++)
@@ -698,7 +698,7 @@ void dw_sbvar_variance_decomposition_command_line(int nargs, char **args)
 		      }
 		    else
 		      {
-			if (tvd=variance_decomposition_mean_regime(posterior_file,thin,s,horizon,model,type))
+			if ((tvd=variance_decomposition_mean_regime(posterior_file,thin,s,horizon,model,type)))
 			  {
 			    NormalizeVarianceDecomposition(tvd,p);
 			    ReorderVarianceDecomposition(tvd,p);
@@ -718,12 +718,12 @@ void dw_sbvar_variance_decomposition_command_line(int nargs, char **args)
 		  sprintf(buffer=(char*)dw_malloc(strlen(fmt) + 10),fmt,s);
 		  out_filename=CreateFilenameFromTag(buffer,cmd->out_tag,cmd->out_directory);
 		  dw_free(buffer);
-		  if (f_out=fopen(out_filename,"wt"))
+		  if ((f_out=fopen(out_filename,"wt")))
 		    {		
 		      printf("Constructing variance decomposition - regime %d\n",s);
 		      if (percentiles)
 			{
-			  if (histogram=variance_decomposition_percentiles_regime(posterior_file,thin,s,horizon,model,type))
+			  if ((histogram=variance_decomposition_percentiles_regime(posterior_file,thin,s,horizon,model,type)))
 			    {
 			      tvd=CreateMatrix(horizon,p->nvars*p->nvars);
 			      for (i=0; i < DimV(percentiles); i++)
@@ -739,7 +739,7 @@ void dw_sbvar_variance_decomposition_command_line(int nargs, char **args)
 			}
 		      else
 			{
-			  if (tvd=variance_decomposition_mean_regime(posterior_file,thin,s,horizon,model,type))
+			  if ((tvd=variance_decomposition_mean_regime(posterior_file,thin,s,horizon,model,type)))
 			    {
 			      NormalizeVarianceDecomposition(tvd,p);
 			      ReorderVarianceDecomposition(tvd,p);
@@ -769,12 +769,12 @@ void dw_sbvar_variance_decomposition_command_line(int nargs, char **args)
 		  else
 		    fmt="%svar_decomp_mean_filtered_%s.out";
 		out_filename=CreateFilenameFromTag(fmt,cmd->out_tag,cmd->out_directory);
-		if (f_out=fopen(out_filename,"wt"))
+		if ((f_out=fopen(out_filename,"wt")))
 		  {
 		    printf("Constructing variance decomposition - %d draws of regimes per posterior value\n",draws);
 		    if (percentiles)
 		      {
-			if (histogram=variance_decomposition_percentiles(draws,posterior_file,thin,ergodic,horizon,model,type))
+			if ((histogram=variance_decomposition_percentiles(draws,posterior_file,thin,ergodic,horizon,model,type)))
 			  {
 			    tvd=CreateMatrix(horizon,p->nvars*p->nvars);
 			    for (i=0; i < DimV(percentiles); i++)
@@ -790,7 +790,7 @@ void dw_sbvar_variance_decomposition_command_line(int nargs, char **args)
 		      }
 		    else
 		      {
-			if (tvd=variance_decomposition_mean(draws,posterior_file,thin,ergodic,horizon,model,type))
+			if ((tvd=variance_decomposition_mean(draws,posterior_file,thin,ergodic,horizon,model,type)))
 			  {
 			    NormalizeVarianceDecomposition(tvd,p);
 			    ReorderVarianceDecomposition(tvd,p);
