@@ -452,11 +452,13 @@ TMarkovStateVariable* CreateMarkovStateVariable_base(int nlags_encoded, TMarkovS
     }
   else
     if (sv->routines->DuplicateInfo  && (dup_info=sv->routines->DuplicateInfo(sv->info)))
-      if (dup_routines=DuplicateQRoutines(sv->routines))
-	return CreateMarkovStateVariable_Single(sv->nbasestates,sv->nfree,nlags_encoded,dup_routines,dup_info);
-      else
-	if (sv->routines->FreeInfo) sv->routines->FreeInfo(dup_info);
- 
+      {
+        if ((dup_routines=DuplicateQRoutines(sv->routines)))
+          return CreateMarkovStateVariable_Single(sv->nbasestates,sv->nfree,nlags_encoded,dup_routines,dup_info);
+        else
+          if (sv->routines->FreeInfo) sv->routines->FreeInfo(dup_info);
+      }
+
   return (TMarkovStateVariable*)NULL;
 }
 
@@ -467,8 +469,8 @@ TMarkovStateVariable* CreateMarkovStateVariable_base(int nlags_encoded, TMarkovS
 TMarkovStateVariable* CreateMarkovStateVariable_lags(int nlags_encoded, TMarkovStateVariable *sv)
 {  
   TMarkovStateVariable **sv_array;
-  if (sv_array=(TMarkovStateVariable**)dw_CreateArray_pointer(1,(void (*)(void*))FreeMarkovStateVariable))
-    if (sv_array[0]=DuplicateMarkovStateVariable(sv))
+  if ((sv_array=(TMarkovStateVariable**)dw_CreateArray_pointer(1,(void (*)(void*))FreeMarkovStateVariable)))
+    if ((sv_array[0]=DuplicateMarkovStateVariable(sv)))
       return CreateMarkovStateVariable_Multiple(nlags_encoded,sv_array);
   return (TMarkovStateVariable*)NULL;
 }
@@ -882,33 +884,35 @@ int sv_NormalizeRegimes(int *p, int t, TMarkovStateVariable *sv, TStateModel *mo
       }
   else
     if (sv->routines->Update_q_from_BaseTransitionMatrix)
-      if (sv->nbasestates < sv->nstates)
-	{
-	  if (!(q=dw_malloc(sv->nbasestates*sizeof(int))))
-	    dw_Error(MEM_ERR);
-	  else
-	    {
-	      for (i=sv->nstates-1; i >= 0; i--) q[sv->lag_index[i][0]]=sv->lag_index[p[i]][0];
-	      if (P=InitializePermutation((TPermutation)NULL,q,sv->nbasestates))
-		{
-		  if (ProductMP(sv->baseQ,TransposeProductPM(sv->baseQ,P,sv->baseQ),P))
-		    rtrn=sv->routines->Update_q_from_BaseTransitionMatrix(t,sv,model);
-		  FreePermutation(P);
-		}
-	      else
-		dw_Error(MEM_ERR);
-	      dw_free(q);
-	    }
-	}
-      else
-	if (P=InitializePermutation((TPermutation)NULL,p,sv->nbasestates))
-	  {
-	    if (ProductMP(sv->baseQ,TransposeProductPM(sv->baseQ,P,sv->baseQ),P))
-	      rtrn=sv->routines->Update_q_from_BaseTransitionMatrix(t,sv,model);
-	    FreePermutation(P);
-	  }
-	else
-	  dw_Error(MEM_ERR);
+      {
+        if (sv->nbasestates < sv->nstates)
+          {
+            if (!(q=dw_malloc(sv->nbasestates*sizeof(int))))
+              dw_Error(MEM_ERR);
+            else
+              {
+                for (i=sv->nstates-1; i >= 0; i--) q[sv->lag_index[i][0]]=sv->lag_index[p[i]][0];
+                if ((P=InitializePermutation((TPermutation)NULL,q,sv->nbasestates)))
+                  {
+                    if (ProductMP(sv->baseQ,TransposeProductPM(sv->baseQ,P,sv->baseQ),P))
+                      rtrn=sv->routines->Update_q_from_BaseTransitionMatrix(t,sv,model);
+                    FreePermutation(P);
+                  }
+                else
+                  dw_Error(MEM_ERR);
+                dw_free(q);
+              }
+          }
+        else
+          if ((P=InitializePermutation((TPermutation)NULL,p,sv->nbasestates)))
+            {
+              if (ProductMP(sv->baseQ,TransposeProductPM(sv->baseQ,P,sv->baseQ),P))
+                rtrn=sv->routines->Update_q_from_BaseTransitionMatrix(t,sv,model);
+              FreePermutation(P);
+            }
+          else
+            dw_Error(MEM_ERR);
+      }
   return rtrn;
 }
 /*******************************************************************************/
@@ -1398,7 +1402,7 @@ int DrawStatesFromTransitionMatrices(TStateModel *model)
   TMarkovStateVariable *sv=model->sv;
   TVector p;
 
-  if (p=CreateVector(sv->nstates))
+  if ((p=CreateVector(sv->nstates)))
     {
       if (sv->routines->Probability_s0(p,sv))
 	{
@@ -1728,7 +1732,7 @@ TMatrix ForecastMean(TMatrix F, int T, int horizon, TStateModel *model)
   return F;
 }
 
-TMatrix ForecastRandom(TMatrix F, int T, int horizon, TStateModel *model)
+TMatrix ForecastRandom(__attribute__ ((unused)) TMatrix F, __attribute__ ((unused)) int T, __attribute__ ((unused)) int horizon, __attribute__ ((unused)) TStateModel *model)
 {
   return (TMatrix)NULL;
 }
@@ -1876,7 +1880,7 @@ TVector ExpectationSingleStep_StatesIntegratedOut(TVector y, int t, TStateModel
   return y;
 }
 
-TVector ExpectedError(TVector epsilon, int t, TStateModel *model)
+TVector ExpectedError(TVector epsilon, __attribute__ ((unused)) int t, __attribute__ ((unused)) TStateModel *model)
 {
 
 
@@ -2052,7 +2056,7 @@ TVector ProbabilitiesState(TVector p, int s, TStateModel *model)
      where S(t+1,T)={s[t+1],...,s[T]}.  The second of these facts is proven in
      the related paper.
 */
-PRECISION LogProbabilityStates(int *S, TStateModel *model)
+PRECISION LogProbabilityStates(__attribute__ ((unused)) int *S, __attribute__ ((unused)) TStateModel *model)
 {
   printf("LogProbabilityStates() not implemented\n");
   dw_exit(0);
