@@ -14,7 +14,7 @@ function dyn_saveas(h, fname, nodisplay, graph_format)
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2012-2019 Dynare Team
+% Copyright © 2012-2019 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -52,17 +52,12 @@ if any(strcmp('pdf',cellstr(graph_format)))
     print(h,'-dpdf',[fname,'.pdf'])
 end
 if any(strcmp('fig',cellstr(graph_format)))
+    if nodisplay
+        set(h,'CreateFcn','set(gcf, ''Visible'',''on'')') ;
+    end
     if isoctave
-        error('Octave cannot create fig files!')
+        saveas(h,[fname '.ofig']);
     else
-        if nodisplay
-            %  THE FOLLOWING LINES COULD BE USED IF BUGS/PROBLEMS ARE REPORTED USING LINE 60
-            %             set(h,'Units','Normalized')
-            %             mypos=get(h,'Position');
-            %             set(h,'Position',[-1 -1 mypos(3:4)])
-            %             set(h, 'Visible','on');
-            set(h,'CreateFcn','set(gcf, ''Visible'',''on'')') ;
-        end
         saveas(h,[fname '.fig']);
     end
 end
