@@ -16,7 +16,7 @@ function dynareroot = dynare_config(path_to_dynare)
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2001-2021 Dynare Team
+% Copyright © 2001-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -42,38 +42,45 @@ dynareroot = strrep(which('dynare'),'dynare.m','');
 origin = pwd();
 cd([dynareroot '/..'])
 
-p = {'/distributions/' ; ...
+p = {'/../contrib/ms-sbvar/TZcode/MatlabFiles/' ; ...
+     '/accessors/' ; ...
+     '/AIM/' ; ...
+     '/backward/' ; ...
+     '/cli/' ; ...
+     '/convergence_diagnostics/' ; ...
+     '/discretionary_policy/' ; ...
+     '/distributions/' ; ...
+     '/ep/' ; ...
+     '/estimation/'; ...
+     '/estimation/smc/'; ...
+     '/estimation/resampler/'; ...
      '/kalman/' ; ...
      '/kalman/likelihood' ; ...
-     '/AIM/' ; ...
-     '/partial_information/' ; ...
-     '/perfect-foresight-models/' ; ...
+     '/latex/' ; ...
+     '/lmmcp/' ; ...
+     '/dseries/src/' ; ...
+     '/reporting/' ; ...
+     '/matrix_solver/'; ...
+     '/moments/'; ...
      '/ms-sbvar/' ; ...
      '/ms-sbvar/identification/' ; ...
-     '/../contrib/ms-sbvar/TZcode/MatlabFiles/' ; ...
-     '/../contrib/jsonlab/' ; ...
-     '/parallel/' ; ...
-     '/particles/src' ; ...
-     '/gsa/' ; ...
-     '/ep/' ; ...
-     '/backward/' ; ...
-     '/convergence_diagnostics/' ; ...
-     '/cli/' ; ...
-     '/lmmcp/' ; ...
-     '/optimization/' ; ...
+     '/nonlinear-filters/' ; ...
      '/ols/' ; ...
+     '/optimal_policy/' ; ...
+     '/optimization/' ; ...
      '/pac-tools/' ; ...
-     '/discretionary_policy/' ; ...
-     '/accessors/' ; ...
-     '/modules/dseries/src/' ; ...
-     '/utilities/doc/' ; ...
-     '/utilities/tests/src/' ; ...
+     '/parallel/' ; ...
+     '/partial_information/' ; ...
+     '/perfect-foresight-models/' ; ...
+     '/shock_decomposition/' ; ...
+     '/stochastic_solver/' ; ...
      '/utilities/dataset/' ; ...
+     '/utilities/doc/' ; ...
+     '/utilities/estimation/' ; ...
      '/utilities/general/' ; ...
      '/utilities/graphics/' ; ...
-     '/utilities/version/' ; ...
-     '/modules/reporting/src/' ; ...
-     '/modules/reporting/macros/'};
+     '/utilities/tests/src/' ; ...
+     '/utilities/version/'};
 
 % For functions that exist only under some Octave versions
 % or some MATLAB versions, and for which we provide some replacement functions
@@ -85,12 +92,6 @@ if ~isoctave
     p{end+1} = '/missing/vec';
 end
 
-%% intersect(…, 'stable') and unique(…, 'stable') doen't exist in Octave < 6
-if isoctave && octave_ver_less_than('6')
-    p{end+1} = '/missing/intersect_stable';
-    p{end+1} = '/missing/unique_stable';
-end
-
 % Replacements for functions of the MATLAB statistics toolbox
 if isoctave
     % Under Octave, these functions are in the statistics Forge package.
@@ -110,26 +111,26 @@ if ~exist('struct2array')
     p{end+1} = '/missing/struct2array';
 end
 
-% isfile is missing in MATLAB < R2017b
-if ~isoctave && matlab_ver_less_than('9.3')
-    p{end+1} = '/missing/isfile';
-end
-
-% contains and splitlines don't exist in Octave and in MATLAB < R2016b
-if isoctave || matlab_ver_less_than('9.1')
+% contains and splitlines don't exist in Octave
+if isoctave
     p{end+1} = '/missing/contains';
     p{end+1} = '/missing/splitlines';
 end
 
-% datetime doesn't exist in Octave and in MATLAB < R2014b
-if isoctave || matlab_ver_less_than('8.4')
+% datetime doesn't exist in Octave
+if isoctave
     p{end+1} = '/missing/datetime';
 end
 
+% intersect with 'stable' flag is broken before Octave 8.4, bug #60347
+if isoctave && octave_ver_less_than('8.4')
+    p{end+1} = '/missing/intersect_stable';
+end
+
 P = cellfun(@(c)[dynareroot(1:end-1) c], p, 'uni',false);
 
 % Get mex files folder(s)
-mexpaths = add_path_to_mex_files(dynareroot, false);
+mexpaths = get_path_to_mex_files(dynareroot);
 
 % Add mex files folder(s)
 P(end+1:end+length(mexpaths)) = mexpaths;
