@@ -1,6 +1,11 @@
-function pfm = setup_stochastic_perfect_foresight_model_solver(DynareModel,DynareOptions,DynareOutput)
+function pfm = setup_stochastic_perfect_foresight_model_solver(M_,options_,oo_)
+% pfm = setup_stochastic_perfect_foresight_model_solver(M_,options_,oo_)
+% INPUTS
+%  o M_                     [struct]    Dynare's model structure
+%  o options_               [struct]    Dynare's options structure
+%  o oo_                    [struct]    Dynare's results structure
 
-% Copyright (C) 2013-2020 Dynare Team
+% Copyright © 2013-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -17,15 +22,15 @@ function pfm = setup_stochastic_perfect_foresight_model_solver(DynareModel,Dynar
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
-pfm.lead_lag_incidence = DynareModel.lead_lag_incidence;
-pfm.ny = DynareModel.endo_nbr;
-pfm.Sigma = DynareModel.Sigma_e;
+pfm.lead_lag_incidence = M_.lead_lag_incidence;
+pfm.ny = M_.endo_nbr;
+pfm.Sigma = M_.Sigma_e;
 if det(pfm.Sigma) > 0
     pfm.Omega = chol(pfm.Sigma,'upper'); % Sigma = Omega'*Omega
 end
 pfm.number_of_shocks = length(pfm.Sigma);
-pfm.stochastic_order = DynareOptions.ep.stochastic.order;
-pfm.max_lag = DynareModel.maximum_endo_lag;
+pfm.stochastic_order = options_.ep.stochastic.order;
+pfm.max_lag = M_.maximum_endo_lag;
 if pfm.max_lag > 0
     pfm.nyp = nnz(pfm.lead_lag_incidence(1,:));
     pfm.iyp = find(pfm.lead_lag_incidence(1,:)>0);
@@ -35,7 +40,7 @@ else
 end
 pfm.ny0 = nnz(pfm.lead_lag_incidence(pfm.max_lag+1,:));
 pfm.iy0 = find(pfm.lead_lag_incidence(pfm.max_lag+1,:)>0);
-if DynareModel.maximum_endo_lead
+if M_.maximum_endo_lead
     pfm.nyf = nnz(pfm.lead_lag_incidence(pfm.max_lag+2,:));
     pfm.iyf = find(pfm.lead_lag_incidence(pfm.max_lag+2,:)>0);
 else
@@ -44,15 +49,15 @@ else
 end
 pfm.nd = pfm.nyp+pfm.ny0+pfm.nyf;
 pfm.nrc = pfm.nyf+1;
-pfm.isp = [1:pfm.nyp];
-pfm.is = [pfm.nyp+1:pfm.ny+pfm.nyp];
+pfm.isp = 1:pfm.nyp;
+pfm.is = pfm.nyp+1:pfm.ny+pfm.nyp;
 pfm.isf = pfm.iyf+pfm.nyp;
-pfm.isf1 = [pfm.nyp+pfm.ny+1:pfm.nyf+pfm.nyp+pfm.ny+1];
-pfm.iz = [1:pfm.ny+pfm.nyp+pfm.nyf];
-pfm.periods = DynareOptions.ep.periods;
-pfm.steady_state = DynareOutput.steady_state;
-pfm.params = DynareModel.params;
-if DynareModel.maximum_endo_lead
+pfm.isf1 = pfm.nyp+pfm.ny+1:pfm.nyf+pfm.nyp+pfm.ny+1;
+pfm.iz = 1:pfm.ny+pfm.nyp+pfm.nyf;
+pfm.periods = options_.ep.periods;
+pfm.steady_state = oo_.steady_state;
+pfm.params = M_.params;
+if M_.maximum_endo_lead
     pfm.i_cols_1 = nonzeros(pfm.lead_lag_incidence(pfm.max_lag+(1:2),:)');
     pfm.i_cols_A1 = find(pfm.lead_lag_incidence(pfm.max_lag+(1:2),:)');
 else
@@ -66,9 +71,9 @@ else
 end
 pfm.i_cols_j = 1:pfm.nd;
 pfm.i_upd = pfm.ny+(1:pfm.periods*pfm.ny);
-if ~DynareOptions.bytecode
-    pfm.dynamic_model = str2func([DynareModel.fname,'.dynamic']);
+if ~options_.bytecode
+    pfm.dynamic_model = str2func([M_.fname,'.dynamic']);
 end
-pfm.verbose = DynareOptions.ep.verbosity;
-pfm.maxit_ = DynareOptions.simul.maxit;
-pfm.tolerance = DynareOptions.dynatol.f;
+pfm.verbose = options_.ep.verbosity;
+pfm.maxit_ = options_.simul.maxit;
+pfm.tolerance = options_.dynatol.f;
