@@ -1,6 +1,6 @@
-function o2WysrOISH  = load_m_file_data_legacy(datafile, U7ORsJ0vy3) % --*-- Unitary tests --*--
-
-% Copyright (C) 2014-2017 Dynare Team
+function o2WysrOISH  = load_m_file_data_legacy(datafile, U7ORsJ0vy3)
+% o2WysrOISH  = load_m_file_data_legacy(datafile, U7ORsJ0vy3)
+% Copyright © 2014-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -18,7 +18,7 @@ function o2WysrOISH  = load_m_file_data_legacy(datafile, U7ORsJ0vy3) % --*-- Uni
 % along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 cXDHdrXnqo5KwwVpTRuc6OprAW = datafile(1:end-2);
-[pathtocXDHdrXnqo5KwwVpTRuc6OprAW,cXDHdrXnqo5KwwVpTRuc6OprAW,~] = fileparts(cXDHdrXnqo5KwwVpTRuc6OprAW);
+[pathtocXDHdrXnqo5KwwVpTRuc6OprAW,cXDHdrXnqo5KwwVpTRuc6OprAW] = fileparts(cXDHdrXnqo5KwwVpTRuc6OprAW);
 
 if ~isempty(pathtocXDHdrXnqo5KwwVpTRuc6OprAW)
     % We need to change directory, first we keep the current directory in memory...
@@ -68,7 +68,7 @@ end
 % Check that all the vectors have the same number of elements.
 RXZzmKFPFK = numel(eval(U7ORsJ0vy3{1}));
 for uAiwEPcc3Q=2:length(U7ORsJ0vy3)
-    if ~isequal(numel(eval(U7ORsJ0vy3{1})), RXZzmKFPFK)
+    if ~isequal(numel(eval(U7ORsJ0vy3{uAiwEPcc3Q})), RXZzmKFPFK)
         error('All vectors must have the same number of elements (%s has %i elements while %s has %i elements)!', U7ORsJ0vy3{1}, numel(eval(U7ORsJ0vy3{1})), U7ORsJ0vy3{uAiwEPcc3Q}, numel(eval(U7ORsJ0vy3{uAiwEPcc3Q})));
     end
 end
@@ -78,7 +78,7 @@ JSmvfqTSXT = repmat(' vec(%s) ', 1, length(U7ORsJ0vy3));
 VbO4y7zOlh = sprintf('[%s]', JSmvfqTSXT);
 o2WysrOISH = dseries(eval(sprintf(VbO4y7zOlh, U7ORsJ0vy3{:})), [], U7ORsJ0vy3);
 
-return
+return % --*-- Unit tests --*--
 
 %@test:1
 % Write a data file
