@@ -1,19 +1,19 @@
 function o = loadjson_(jsonfilename)
 
-% Reads a json file using jsonlab toolbox or jsondecode builtin if available.
+% Reads a JSON file using jsondecode builtin.
+%
+% Returns the output in a format consistent with the output of the JSONlab
+% toolbox, that we used to rely on (jsondecode builtin was introduced in MATLAB
+% R2016b and in Octave 7). Now we no longer depend on JSONlab, but for
+% historical reasons we still use its format.
 %
 % INPUTS
 % - jsonfilename   [char]      1×n char array, name of the JSON file.
 %
 % OUTPUTS
 % - o              [struct]    content of the JSON file.
-%
-% REMARKS
-% jsondecode builtin was introduced in Matlab R2016b and is not
-% available under Octave. Old Matlab versions and Octave use
-% jsonlab as fallback. 
 
-% Copyright (C) 2020-2021 Dynare Team
+% Copyright © 2020-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -30,12 +30,21 @@ function o = loadjson_(jsonfilename)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
-if isoctave() || matlab_ver_less_than('9.1')
-    o = loadjson(jsonfilename);
-    return
-end
-
 json = fileread(jsonfilename);
 
-o = jsondecode(json); clear('json');
-o = convertjsondecode(o);
+o = jsondecode(json);
+
+clear json
+
+fnames = fieldnames(o);
+
+for i=1:length(fnames)
+    tmp = o.(fnames{i});
+    if isstruct(tmp) && length(tmp)>1
+        TMP = cell(length(tmp), 1);
+        for j=1:length(tmp)
+            TMP{j} = tmp(j);
+        end
+        o.(fnames{i}) = TMP;
+    end
+end
