@@ -11,7 +11,7 @@ function sigma = long_run_variance(data,band)
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2009-2010 Dynare Team
+% Copyright © 2009-2010 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -31,7 +31,7 @@ function sigma = long_run_variance(data,band)
 verbose = 1;
 
 if nargin<2
-    [T,m] = size(data);
+    [T,~] = size(data);
     band = ceil(T^(1/4));
     if verbose
         disp(['Bandwidth parameter is equal to ' num2str(band) '.'])
