@@ -56,9 +56,9 @@ function [x,f,exitflag,n_f_evals,n_grad_evals,n_constraint_evals,n_constraint_gr
 % (version 1.1, Matlab, C, FORTRAN). University of Graz, Graz, 1997.
 %
 %
-% Copyright (C) 1997-2008, Alexei Kuntsevich and Franz Kappel
-% Copyright (C) 2008-2015 Giovanni Lombardo
-% Copyright (C) 2015-2017 Dynare Team
+% Copyright © 1997-2008, Alexei Kuntsevich and Franz Kappel
+% Copyright © 2008-2015 Giovanni Lombardo
+% Copyright © 2015-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -761,7 +761,7 @@ while 1
             nsteps(2:kg)=nsteps(1:kg-1);
         end
         nsteps(1)=dx/(abs(h)*norm(g0));
-        kk=sum(nsteps(1:kg).*[kg:-1:1])/sum([kg:-1:1]);
+        kk=sum(nsteps(1:kg).*[kg:-1:1])/sum(kg:-1:1);
         if     kk>des
             if kg==1
                 h=h*(kk-des+1);
