@@ -5,7 +5,7 @@ function  y=PCL_Part_info_irf( H, varobs, ivar, M_, dr, irfpers,ii)
 % Pearlman, Currie and Levine 1986 solution.
 % 22/10/06 - Version 2 for new Riccati with 4 params instead 5
 
-% Copyright (C) 2006-2018 Dynare Team
+% Copyright © 2006-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -116,7 +116,7 @@ rr=DD*QQ*DD'+RR;
 ZSIG0=disc_riccati_fast(ff,DD,rr,hh);
 PP=ZSIG0 +QQ;
 
-exo_names=M_.exo_names(M_.exo_names_orig_ord);
+exo_names=M_.exo_names;
 
 DPDR=DD*PP*DD'+RR;
 I_DPDR=inv(DPDR);
