@@ -40,7 +40,7 @@ function [dr,info,M_,options_,oo_] = dr1_PI(dr,task,M_,options_,oo_)
 %   none.
 %
 
-% Copyright (C) 1996-2018 Dynare Team
+% Copyright © 1996-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -85,12 +85,12 @@ if options_.ramsey_policy && ~options_.ACES_solver
         M_.maximum_lag = orig_model.maximum_lag;
         M_.maximum_endo_lag = orig_model.maximum_endo_lag;
     end
-    old_solve_algo = options_.solve_algo;
-    %  options_.solve_algo = 1;
-    opt = options_;
-    opt.jacobian_flag = false;
-    oo_.steady_state = dynare_solve('ramsey_static',oo_.steady_state,opt,M_,options_,oo_,it_);
-    options_.solve_algo = old_solve_algo;
+    o_jacobian_flag = options_.jacobian_flag;
+    options_.jacobian_flag = false;
+    oo_.steady_state = dynare_solve('ramsey_static', oo_.steady_state, ...
+                                    options_.ramsey.maxit, options_.solve_tolf, options_.solve_tolx, ...
+                                    options_, M_, options_, oo_, it_);
+    options_.jacobian_flag = o_jacobian_flag;
     [~,~,multbar] = ramsey_static(oo_.steady_state,M_,options_,oo_,it_);
     [jacobia_,M_] = ramsey_dynamic(oo_.steady_state,multbar,M_,options_,oo_,it_);
     klen = M_.maximum_lag + M_.maximum_lead + 1;
@@ -124,7 +124,7 @@ else
         lq_instruments.tct_ruleids=tct_ruleids;
         %if isfield(lq_instruments,'xsopt_SS') %% changed by BY
         [~, lq_instruments.xsopt_SS,lq_instruments.lmopt_SS,s2,check] = opt_steady_get;%% changed by BY
-        [qc, DYN_Q] = QPsolve(lq_instruments, s2, check); %% added by BY
+        [~, DYN_Q] = QPsolve(lq_instruments, s2, check); %% added by BY
         z = repmat(lq_instruments.xsopt_SS,1,klen);
     else
         z = repmat(dr.ys,1,klen);
@@ -157,7 +157,7 @@ if options_.debug
     save([M_.dname filesep 'Output' filesep M_.fname '_debug.mat'],'jacobia_')
 end
 
-dr=set_state_space(dr,M_,options_);
+dr=set_state_space(dr,M_);
 kstate = dr.kstate;
 nstatic = M_.nstatic;
 nfwrd = M_.nfwrd;
@@ -194,7 +194,7 @@ if(options_.ACES_solver)
             for i=1:num_inst
                 i_tmp = strmatch(deblank(lq_instruments.names(i,:)), M_.endo_names,'exact');
                 if isempty(i_tmp)
-                    error (['One of the specified instrument variables does not exist']) ;
+                    error ('One of the specified instrument variables does not exist') ;
                 else
                     i_var(i) = i_tmp;
                 end
@@ -303,7 +303,7 @@ if ( M_.maximum_lag <= 1) && (M_.maximum_lead <= 1)
         if num_exp_0>0
             AA3(:,exp_0)=AA1(:,exp_0);
             XX0=zeros(nendo,num_exp_0);
-            AA1(:,exp_0)=XX0(:,[1:num_exp_0])
+            AA1(:,exp_0)=XX0(:,1:num_exp_0)
         end
     end
 end
