@@ -148,7 +148,7 @@ if isempty(marginal_linearization_previous_raw_sims)
 else
     shareorig = marginal_linearization_previous_raw_sims.sim1.homotopy_completion_share;
     endoorig = marginal_linearization_previous_raw_sims.sim1.endo_simul;
-    exoorig = marginal_linearization_previous_raw_sims.sim1.exo_simul;
+    exoorig = shareorig*oo_.exo_simul + (1-shareorig)*exobase;
 end
 [completed_share, endo_simul, exo_simul, steady_state, exo_steady_state, iteration, maxerror, solver_iter, per_block_status] = homotopy_loop(M_,options_,oo_,options_.simul.homotopy_max_completion_share, shareorig, endoorig, exoorig, endobase, exobase, initperiods, simperiods, lastperiods, recompute_final_steady_state, oo_.steady_state, oo_.exo_steady_state);
 
@@ -202,7 +202,7 @@ elseif options_.simul.homotopy_marginal_linearization_fallback > 0 && completed_
     else
         shareorig = marginal_linearization_previous_raw_sims.sim2.homotopy_completion_share;
         endoorig = marginal_linearization_previous_raw_sims.sim2.endo_simul;
-        exoorig = marginal_linearization_previous_raw_sims.sim2.exo_simul;
+        exoorig = shareorig*oo_.exo_simul + (1-shareorig)*exobase;
     end
     extra_share = completed_share - options_.simul.homotopy_marginal_linearization_fallback;
     if ~options_.noprint
