@@ -11,7 +11,7 @@ function print_bytecode_static_model()
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2001-2017 Dynare Team
+% Copyright © 2001-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -27,9 +27,15 @@ function print_bytecode_static_model()
 %
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
-global options_
+
+global M_ options_ oo_
+
 if options_.bytecode
-    bytecode('print','static');
+    if options_.block
+        bytecode('print', 'static', 'block_decomposed', M_, options_, oo_.steady_state, [oo_.exo_steady_state; oo_.exo_det_steady_state], M_.params);
+    else
+        bytecode('print', 'static', M_, options_, oo_.steady_state, [oo_.exo_steady_state; oo_.exo_det_steady_state], M_.params);
+    end
 else
     disp('You have to use bytecode option in model command to use print_bytecode_static_model');
 end
