@@ -17,7 +17,7 @@ function dyn_data_01=read_variables(file_name_01,var_names_01,dyn_data_01,xls_sh
 % all local variables have complicated names in order to avoid name
 % conflicts with possible user variable names
 
-% Copyright (C) 2005-2017 Dynare Team
+% Copyright © 2005-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -89,7 +89,7 @@ switch (extension)
         dyn_data_01(:,dyn_i_01) = dyn_tmp_01;
     end
   case { '.xls', '.xlsx' }
-    [freq,init,data,varlist] = load_xls_file_data(fullname,xls_sheet,xls_range);
+    [~,~,data,varlist] = load_xls_file_data(fullname,xls_sheet,xls_range);
     for dyn_i_01=1:var_size_01
         iv = strmatch(strtrim(var_names_01{dyn_i_01}),varlist,'exact');
         if ~isempty(iv)
@@ -105,7 +105,7 @@ switch (extension)
         end
     end
   case '.csv'
-    [freq,init,data,varlist] = load_csv_file_data(fullname);
+    [~,~,data,varlist] = load_csv_file_data(fullname);
     for dyn_i_01=1:var_size_01
         iv = strmatch(var_names_01{dyn_i_01},varlist,'exact');
         if ~isempty(iv)
@@ -126,5 +126,4 @@ switch (extension)
 end
 
 cd(old_pwd)
-disp(sprintf('Loading %d observations from %s\n',...
-             size(dyn_data_01,1),fullname))
+dprintf('Loading %d observations from %s', size(dyn_data_01, 1), fullname)
