@@ -1,8 +1,8 @@
-function update_all_parameters_in_workspace(DynareModel)
-
+function update_all_parameters_in_workspace(M_)
+% update_all_parameters_in_workspace(M_)
 % Updates all parameter values in Matlab/Octave base workspace.
 
-% Copyright (C) 2018 Dynare Team
+% Copyright © 2018-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -19,6 +19,6 @@ function update_all_parameters_in_workspace(DynareModel)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
-for i=1:length(DynareModel.params)
-    assignin('base', DynareModel.param_names{i}, DynareModel.params(i));
+for i=1:length(M_.params)
+    assignin('base', M_.param_names{i}, M_.params(i));
 end
\ No newline at end of file
