@@ -1,5 +1,5 @@
 /*
- * Copyright © 2009-2020 Dynare Team
+ * Copyright © 2009-2023 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -17,8 +17,8 @@
  * along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef _DYNMEX_H
-#define _DYNMEX_H
+#ifndef DYNMEX_H
+#define DYNMEX_H
 
 #if !defined(MATLAB_MEX_FILE) && !defined(OCTAVE_MEX_FILE)
 # error You must define either MATLAB_MEX_FILE or OCTAVE_MEX_FILE
@@ -26,8 +26,4 @@
 
 #include <mex.h>
 
-#if defined(MATLAB_MEX_FILE) && MATLAB_VERSION < 0x0805
-# define mxIsScalar(x) (mxGetM(x) == 1 && mxGetN(x) == 1)
-#endif
-
 #endif
