@@ -1,6 +1,6 @@
 /*
  * Copyright © 2005-2011 Ondra Kamenik
- * Copyright © 2019-2020 Dynare Team
+ * Copyright © 2019-2022 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -26,19 +26,17 @@
 #include "int_power.hh"
 
 void
-gen_sylv_solve(int order, int n, int m, int zero_cols,
-               const ConstVector &A, const ConstVector &B,
-               const ConstVector &C, Vector &X)
+gen_sylv_solve(int order, int n, int m, int zero_cols, const ConstVector& A, const ConstVector& B,
+               const ConstVector& C, Vector& X)
 {
   GeneralSylvester s(order, n, m, zero_cols, A, B, C, X, false);
   s.solve();
 }
 
-mxArray *
-gen_sylv_solve_and_check(int order, int n, int m, int zero_cols,
-                         const ConstVector &A, const ConstVector &B,
-                         const ConstVector &C, const ConstVector &D,
-                         Vector &X)
+mxArray*
+gen_sylv_solve_and_check(int order, int n, int m, int zero_cols, const ConstVector& A,
+                         const ConstVector& B, const ConstVector& C, const ConstVector& D,
+                         Vector& X)
 {
   GeneralSylvester s(order, n, m, zero_cols, A, B, C, X, true);
   s.solve();
@@ -46,23 +44,36 @@ gen_sylv_solve_and_check(int order, int n, int m, int zero_cols,
   return s.getParams().createStructArray();
 }
 
-extern "C" {
+extern "C"
+{
   void
-  mexFunction(int nlhs, mxArray *plhs[],
-              int nhrs, const mxArray *prhs[])
+  mexFunction(int nlhs, mxArray* plhs[], int nhrs, const mxArray* prhs[])
   {
     if (nhrs != 5 || nlhs > 2 || nlhs < 1)
       mexErrMsgTxt("Gensylv: Must have exactly 5 input args and either 1 or 2 output args.");
 
+    if (!(mxIsScalar(prhs[0]) && mxIsNumeric(prhs[0])))
+      mexErrMsgTxt("First argument should be a numeric scalar");
+
     auto order = static_cast<int>(mxGetScalar(prhs[0]));
-    const mxArray *const A = prhs[1];
-    const mxArray *const B = prhs[2];
-    const mxArray *const C = prhs[3];
-    const mxArray *const D = prhs[4];
-    const mwSize *const Adims = mxGetDimensions(A);
-    const mwSize *const Bdims = mxGetDimensions(B);
-    const mwSize *const Cdims = mxGetDimensions(C);
-    const mwSize *const Ddims = mxGetDimensions(D);
+    const mxArray* const A = prhs[1];
+    const mxArray* const B = prhs[2];
+    const mxArray* const C = prhs[3];
+    const mxArray* const D = prhs[4];
+
+    if (!mxIsDouble(A) || mxIsComplex(A) || mxIsSparse(A))
+      mexErrMsgTxt("Matrix A must be a real dense matrix.");
+    if (!mxIsDouble(B) || mxIsComplex(B) || mxIsSparse(B))
+      mexErrMsgTxt("Matrix B must be a real dense matrix.");
+    if (!mxIsDouble(C) || mxIsComplex(C) || mxIsSparse(C))
+      mexErrMsgTxt("Matrix C must be a real dense matrix.");
+    if (!mxIsDouble(D) || mxIsComplex(D) || mxIsSparse(D))
+      mexErrMsgTxt("Matrix D must be a real dense matrix.");
+
+    const mwSize* const Adims = mxGetDimensions(A);
+    const mwSize* const Bdims = mxGetDimensions(B);
+    const mwSize* const Cdims = mxGetDimensions(C);
+    const mwSize* const Ddims = mxGetDimensions(D);
 
     if (Adims[0] != Adims[1])
       mexErrMsgTxt("Matrix A must be a square matrix.");
@@ -80,10 +91,10 @@ extern "C" {
     auto n = static_cast<int>(Adims[0]);
     auto m = static_cast<int>(Cdims[0]);
     auto zero_cols = static_cast<int>(Bdims[0] - Bdims[1]);
-    mxArray *X = mxCreateDoubleMatrix(Ddims[0], Ddims[1], mxREAL);
+    mxArray* X = mxCreateDoubleMatrix(Ddims[0], Ddims[1], mxREAL);
     // copy D to X
-    ConstVector Avec{A}, Bvec{B}, Cvec{C}, Dvec{D};
-    Vector Xvec{X};
+    ConstVector Avec {A}, Bvec {B}, Cvec {C}, Dvec {D};
+    Vector Xvec {X};
     Xvec = Dvec;
     // solve (or solve and check)
     try
@@ -93,7 +104,7 @@ extern "C" {
         else if (nlhs == 2)
           plhs[1] = gen_sylv_solve_and_check(order, n, m, zero_cols, Avec, Bvec, Cvec, Dvec, Xvec);
       }
-    catch (const SylvException &e)
+    catch (const SylvException& e)
       {
         mexErrMsgTxt(e.getMessage().c_str());
       }
