@@ -1,5 +1,5 @@
 /*
- * Copyright © 2019-2022 Dynare Team
+ * Copyright © 2019-2023 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -21,29 +21,30 @@
 #include "Driver.hh"
 
 #include <fstream>
+#include <utility>
 
 using namespace macro;
 
 void
-Eval::interpret(ostream &output, Environment &env, vector<filesystem::path> &paths)
+Eval::interpret(ostream& output, Environment& env, [[maybe_unused]] vector<filesystem::path>& paths)
 {
   try
     {
       output << expr->eval(env)->to_string();
     }
-  catch (StackTrace &ex)
+  catch (StackTrace& ex)
     {
       ex.push("Evaluation", location);
       error(ex);
     }
-  catch (exception &e)
+  catch (exception& e)
     {
       error(StackTrace("Evaluation", e.what(), location));
     }
 }
 
 void
-Include::interpret(ostream &output, Environment &env, vector<filesystem::path> &paths)
+Include::interpret(ostream& output, Environment& env, vector<filesystem::path>& paths)
 {
   using namespace filesystem;
   try
@@ -55,7 +56,7 @@ Include::interpret(ostream &output, Environment &env, vector<filesystem::path> &
       ifstream incfile(filename, ios::binary);
       if (incfile.fail())
         {
-          for (const auto &dir : paths)
+          for (const auto& dir : paths)
             {
               incfile = ifstream(dir / filename, ios::binary);
               if (incfile.good())
@@ -65,24 +66,27 @@ Include::interpret(ostream &output, Environment &env, vector<filesystem::path> &
             {
               ostringstream errmsg;
               errmsg << "   * " << current_path().string() << endl;
-              for (const auto &dir : paths)
+              for (const auto& dir : paths)
                 errmsg << "   * " << absolute(dir).string() << endl;
-              error(StackTrace("@#include", "Could not open " + filename.string()
-                               +". The following directories were searched:\n" + errmsg.str(), location));
+              error(StackTrace("@#include",
+                               "Could not open " + filename.string()
+                                   + ". The following directories were searched:\n" + errmsg.str(),
+                               location));
             }
         }
       Driver m;
-      // Calling `string()` method on filename and filename.stem() because of bug in
-      // MinGW 8.3.0 that ignores implicit conversion to string from filename::path.
-      // Test if bug exists when version of MinGW is upgraded on Debian runners
-      m.parse(filename.string(), filename.stem().string(), incfile, false, {}, env, paths, output);
+      /* Calling string() method on filename: not necessary on GNU/Linux and macOS because there is
+         an implicit conversion from from filesystem:path to string (i.e. basic_string<char>), but
+         needed on Windows because the implicit conversion is only to wstring (i.e.
+         basic_string<wchar_t>). */
+      m.parse(filename.string(), incfile, false, {}, env, paths, output);
     }
-  catch (StackTrace &ex)
+  catch (StackTrace& ex)
     {
       ex.push("@#include", location);
       error(ex);
     }
-  catch (exception &e)
+  catch (exception& e)
     {
       error(StackTrace("@#include", e.what(), location));
     }
@@ -90,7 +94,8 @@ Include::interpret(ostream &output, Environment &env, vector<filesystem::path> &
 }
 
 void
-IncludePath::interpret(ostream &output, Environment &env, vector<filesystem::path> &paths)
+IncludePath::interpret([[maybe_unused]] ostream& output, Environment& env,
+                       vector<filesystem::path>& paths)
 {
   using namespace filesystem;
   try
@@ -98,32 +103,19 @@ IncludePath::interpret(ostream &output, Environment &env, vector<filesystem::pat
       StringPtr msp = dynamic_pointer_cast<String>(expr->eval(env));
       if (!msp)
         throw StackTrace("File name does not evaluate to a string");
-#ifdef _WIN32
-      /* Trim trailing slashes and backslashes in the path. This is a
-         workaround for a GCC/MinGW bug present in version 10.2
-         https://gcc.gnu.org/bugzilla/show_bug.cgi?id=88881, that affects
-         gcc-mingw-w64 in Debian “Bullseye” 11. It is fixed in GCC 10.3, and
-         thus should be fixed in Debian “Bookworm” 12.
-         See Madysson/estimation-codes#11. */
-      string ipstr = static_cast<string>(*msp);
-      while (ipstr.size() > 1 && (ipstr.back() == '/' || ipstr.back() == '\\'))
-        ipstr.pop_back();
-      path ip{ipstr};
-#else
       path ip = static_cast<string>(*msp);
-#endif
       if (!is_directory(ip))
         throw StackTrace(ip.string() + " does not evaluate to a valid directory");
       if (!exists(ip))
         warning(StackTrace("@#includepath", ip.string() + " does not exist", location));
       paths.emplace_back(ip);
     }
-  catch (StackTrace &ex)
+  catch (StackTrace& ex)
     {
       ex.push("@#includepath", location);
       error(ex);
     }
-  catch (exception &e)
+  catch (exception& e)
     {
       error(StackTrace("@#includepath", e.what(), location));
     }
@@ -131,7 +123,8 @@ IncludePath::interpret(ostream &output, Environment &env, vector<filesystem::pat
 }
 
 void
-Define::interpret(ostream &output, Environment &env, vector<filesystem::path> &paths)
+Define::interpret([[maybe_unused]] ostream& output, Environment& env,
+                  [[maybe_unused]] vector<filesystem::path>& paths)
 {
   try
     {
@@ -142,12 +135,12 @@ Define::interpret(ostream &output, Environment &env, vector<filesystem::path> &p
       else
         throw StackTrace("LHS of can be either a variable or a function");
     }
-  catch (StackTrace &ex)
+  catch (StackTrace& ex)
     {
       ex.push("@#define", location);
       error(ex);
     }
-  catch (exception &e)
+  catch (exception& e)
     {
       error(StackTrace("@#define", e.what(), location));
     }
@@ -155,18 +148,18 @@ Define::interpret(ostream &output, Environment &env, vector<filesystem::path> &p
 }
 
 void
-Echo::interpret(ostream &output, Environment &env, vector<filesystem::path> &paths)
+Echo::interpret(ostream& output, Environment& env, [[maybe_unused]] vector<filesystem::path>& paths)
 {
   try
     {
       cout << "@#echo (" << getLocation() << "): " << expr->eval(env)->to_string() << endl;
     }
-  catch (StackTrace &ex)
+  catch (StackTrace& ex)
     {
       ex.push("@#echo", location);
       error(ex);
     }
-  catch (exception &e)
+  catch (exception& e)
     {
       error(StackTrace("@#echo", e.what(), location));
     }
@@ -174,25 +167,27 @@ Echo::interpret(ostream &output, Environment &env, vector<filesystem::path> &pat
 }
 
 void
-Error::interpret(ostream &output, Environment &env, vector<filesystem::path> &paths)
+Error::interpret([[maybe_unused]] ostream& output, Environment& env,
+                 [[maybe_unused]] vector<filesystem::path>& paths)
 {
   try
     {
       throw StackTrace(expr->eval(env)->to_string());
     }
-  catch (StackTrace &ex)
+  catch (StackTrace& ex)
     {
       ex.push("@#error", location);
       error(ex);
     }
-  catch (exception &e)
+  catch (exception& e)
     {
       error(StackTrace("@#error", e.what(), location));
     }
 }
 
 void
-EchoMacroVars::interpret(ostream &output, Environment &env, vector<filesystem::path> &paths)
+EchoMacroVars::interpret(ostream& output, Environment& env,
+                         [[maybe_unused]] vector<filesystem::path>& paths)
 {
   if (save)
     env.print(output, vars, location.begin.line, true);
@@ -202,7 +197,7 @@ EchoMacroVars::interpret(ostream &output, Environment &env, vector<filesystem::p
 }
 
 void
-For::interpret(ostream &output, Environment &env, vector<filesystem::path> &paths)
+For::interpret(ostream& output, Environment& env, vector<filesystem::path>& paths)
 {
   ArrayPtr ap;
   try
@@ -211,12 +206,12 @@ For::interpret(ostream &output, Environment &env, vector<filesystem::path> &path
       if (!ap)
         throw StackTrace("The index must loop through an array");
     }
-  catch (StackTrace &ex)
+  catch (StackTrace& ex)
     {
       ex.push("@#for", location);
       error(ex);
     }
-  catch (exception &e)
+  catch (exception& e)
     {
       error(StackTrace("@#for", e.what(), location));
     }
@@ -235,8 +230,11 @@ For::interpret(ostream &output, Environment &env, vector<filesystem::path> &path
             {
               TuplePtr mtp = dynamic_pointer_cast<Tuple>(btp);
               if (index_vec.size() != mtp->size())
-                error(StackTrace("@#for", "Encountered tuple of size " + to_string(mtp->size())
-                                 + " but only have " + to_string(index_vec.size()) + " index variables", location));
+                error(StackTrace("@#for",
+                                 "Encountered tuple of size " + to_string(mtp->size())
+                                     + " but only have " + to_string(index_vec.size())
+                                     + " index variables",
+                                 location));
               else
                 for (size_t j = 0; j < index_vec.size(); j++)
                   env.define(index_vec.at(j), mtp->at(j));
@@ -244,7 +242,7 @@ For::interpret(ostream &output, Environment &env, vector<filesystem::path> &path
         }
 
       bool printLine = true;
-      for (const auto &statement : statements)
+      for (const auto& statement : statements)
         {
           if (printLine)
             {
@@ -258,15 +256,13 @@ For::interpret(ostream &output, Environment &env, vector<filesystem::path> &path
 }
 
 void
-If::interpret(ostream &output, Environment &env, vector<filesystem::path> &paths)
+If::interpret(ostream& output, Environment& env, vector<filesystem::path>& paths)
 {
-  bool first_clause = true;
-  for (const auto & [expr, body] : expr_and_body)
+  for (bool first_clause {true}; const auto& [expr, body] : expr_and_body)
     try
       {
-        if ((ifdef || ifndef) && first_clause)
+        if ((ifdef || ifndef) && exchange(first_clause, false))
           {
-            first_clause = false;
             VariablePtr vp = dynamic_pointer_cast<Variable>(expr);
             if (!vp)
               error(StackTrace(ifdef ? "@#ifdef" : "@#ifndef",
@@ -284,8 +280,8 @@ If::interpret(ostream &output, Environment &env, vector<filesystem::path> &paths
             RealPtr dp = dynamic_pointer_cast<Real>(tmp);
             BoolPtr bp = dynamic_pointer_cast<Bool>(tmp);
             if (!bp && !dp)
-              error(StackTrace("@#if",
-                               "The condition must evaluate to a boolean or a double", location));
+              error(StackTrace("@#if", "The condition must evaluate to a boolean or a double",
+                               location));
             if ((bp && *bp) || (dp && *dp))
               {
                 interpretBody(body, output, env, paths);
@@ -293,12 +289,12 @@ If::interpret(ostream &output, Environment &env, vector<filesystem::path> &paths
               }
           }
       }
-    catch (StackTrace &ex)
+    catch (StackTrace& ex)
       {
         ex.push("@#if", location);
         error(ex);
       }
-    catch (exception &e)
+    catch (exception& e)
       {
         error(StackTrace("@#if", e.what(), location));
       }
@@ -306,16 +302,13 @@ If::interpret(ostream &output, Environment &env, vector<filesystem::path> &paths
 }
 
 void
-If::interpretBody(const vector<DirectivePtr> &body, ostream &output, Environment &env, vector<filesystem::path> &paths)
+If::interpretBody(const vector<DirectivePtr>& body, ostream& output, Environment& env,
+                  vector<filesystem::path>& paths)
 {
-  bool printLine = true;
-  for (const auto &statement : body)
+  for (bool printLine {true}; const auto& statement : body)
     {
-      if (printLine)
-        {
-          statement->printLineInfo(output);
-          printLine = false;
-        }
+      if (exchange(printLine, false))
+        statement->printLineInfo(output);
       statement->interpret(output, env, paths);
     }
 }
