@@ -1,5 +1,5 @@
 /*
- * Copyright © 2019-2020 Dynare Team
+ * Copyright © 2019-2023 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -17,16 +17,18 @@
  * along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+#include <cassert>
+
 #include "Environment.hh"
 #include "Expressions.hh"
 
 using namespace macro;
 
 void
-Environment::define(VariablePtr var, ExpressionPtr value)
+Environment::define(const VariablePtr& var, const ExpressionPtr& value)
 {
   string name = var->getName();
-  if (functions.count(name))
+  if (functions.contains(name))
     throw StackTrace("Variable " + name + " was previously defined as a function");
   variables[move(name)] = value->eval(*this);
 }
@@ -35,13 +37,13 @@ void
 Environment::define(FunctionPtr func, ExpressionPtr value)
 {
   string name = func->getName();
-  if (variables.count(name))
+  if (variables.contains(name))
     throw StackTrace("Variable " + name + " was previously defined as a variable");
   functions[name] = {move(func), move(value)};
 }
 
 ExpressionPtr
-Environment::getVariable(const string &name) const
+Environment::getVariable(const string& name) const
 {
   if (auto it = variables.find(name); it != variables.end())
     return it->second;
@@ -53,7 +55,7 @@ Environment::getVariable(const string &name) const
 }
 
 tuple<FunctionPtr, ExpressionPtr>
-Environment::getFunction(const string &name) const
+Environment::getFunction(const string& name) const
 {
   if (auto it = functions.find(name); it != functions.end())
     return it->second;
@@ -65,50 +67,51 @@ Environment::getFunction(const string &name) const
 }
 
 codes::BaseType
-Environment::getType(const string &name) const
+Environment::getType(const string& name) const
 {
-  return getVariable(name)->eval(const_cast<Environment &>(*this))->getType();
+  return getVariable(name)->eval(const_cast<Environment&>(*this))->getType();
 }
 
 bool
-Environment::isVariableDefined(const string &name) const noexcept
+Environment::isVariableDefined(const string& name) const noexcept
 {
   try
     {
       getVariable(name);
       return true;
     }
-  catch (StackTrace &ex)
+  catch (StackTrace& ex)
     {
       return false;
     }
 }
 
 bool
-Environment::isFunctionDefined(const string &name) const noexcept
+Environment::isFunctionDefined(const string& name) const noexcept
 {
   try
     {
       getFunction(name);
       return true;
     }
-  catch (StackTrace &ex)
+  catch (StackTrace& ex)
     {
       return false;
     }
 }
 
 void
-Environment::print(ostream &output, const vector<string> &vars, int line, bool save) const
+Environment::print(ostream& output, const vector<string>& vars, const optional<int>& line,
+                   bool save) const
 {
   if (!save && !variables.empty())
     output << "Macro Variables:" << endl;
 
   if (vars.empty())
-    for (const auto &it : variables)
+    for (const auto& it : variables)
       printVariable(output, it.first, line, save);
   else
-    for (const auto &it : vars)
+    for (const auto& it : vars)
       if (isVariableDefined(it))
         printVariable(output, it, line, save);
 
@@ -116,32 +119,35 @@ Environment::print(ostream &output, const vector<string> &vars, int line, bool s
     output << "Macro Functions:" << endl;
 
   if (vars.empty())
-    for (const auto &it : functions)
+    for (const auto& it : functions)
       printFunction(output, it.second, line, save);
   else
-    for (const auto &it : vars)
+    for (const auto& it : vars)
       if (isFunctionDefined(it))
-        printFunction(output, functions.find(it)->second, line, save);
+        printFunction(output, functions.at(it), line, save);
 
   if (parent)
     parent->print(output, vars, line, save);
 }
 
 void
-Environment::printVariable(ostream &output, const string &name, int line, bool save) const
+Environment::printVariable(ostream& output, const string& name, const optional<int>& line,
+                           bool save) const
 {
-  output << (save ? "options_.macrovars_line_" + to_string(line) + "." : "  ")
-         << name << " = ";
-  getVariable(name)->eval(const_cast<Environment &>(*this))->print(output, save);
+  assert(!save || line);
+  output << (save ? "options_.macrovars_line_" + to_string(*line) + "." : "  ") << name << " = ";
+  getVariable(name)->eval(const_cast<Environment&>(*this))->print(output, save);
   if (save)
     output << ";";
   output << endl;
 }
 
 void
-Environment::printFunction(ostream &output, const tuple<FunctionPtr, ExpressionPtr> &function, int line, bool save) const
+Environment::printFunction(ostream& output, const tuple<FunctionPtr, ExpressionPtr>& function,
+                           const optional<int>& line, bool save) const
 {
-  output << (save ? "options_.macrovars_line_" + to_string(line) + ".function." : "  ");
+  assert(!save || line);
+  output << (save ? "options_.macrovars_line_" + to_string(*line) + ".function." : "  ");
   if (save)
     {
       get<0>(function)->printName(output);
